Updates the module name in C extension, ensuring it compiles
diff --git a/src/ruby/ext/grpc/rb_byte_buffer.c b/src/ruby/ext/grpc/rb_byte_buffer.c
index f73b12c..8586915 100644
--- a/src/ruby/ext/grpc/rb_byte_buffer.c
+++ b/src/ruby/ext/grpc/rb_byte_buffer.c
@@ -202,9 +202,9 @@
 /* rb_cByteBuffer is the ruby class that proxies grpc_byte_buffer. */
 VALUE rb_cByteBuffer = Qnil;
 
-void Init_google_rpc_byte_buffer() {
+void Init_grpc_byte_buffer() {
   rb_cByteBuffer =
-      rb_define_class_under(rb_mGoogleRpcCore, "ByteBuffer", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "ByteBuffer", rb_cObject);
 
   /* Allocates an object managed by the ruby runtime */
   rb_define_alloc_func(rb_cByteBuffer, grpc_rb_byte_buffer_alloc);
diff --git a/src/ruby/ext/grpc/rb_byte_buffer.h b/src/ruby/ext/grpc/rb_byte_buffer.h
index 322c268..1340c35 100644
--- a/src/ruby/ext/grpc/rb_byte_buffer.h
+++ b/src/ruby/ext/grpc/rb_byte_buffer.h
@@ -42,7 +42,7 @@
 extern VALUE rb_cByteBuffer;
 
 /* Initializes the ByteBuffer class. */
-void Init_google_rpc_byte_buffer();
+void Init_grpc_byte_buffer();
 
 /* grpc_rb_byte_buffer_create_with_mark creates a grpc_rb_byte_buffer with a
  * ruby mark object that will be kept alive while the byte_buffer is alive. */
diff --git a/src/ruby/ext/grpc/rb_call.c b/src/ruby/ext/grpc/rb_call.c
index 5d72307..af5ef25 100644
--- a/src/ruby/ext/grpc/rb_call.c
+++ b/src/ruby/ext/grpc/rb_call.c
@@ -449,9 +449,9 @@
    operations; */
 VALUE rb_eCallError = Qnil;
 
-void Init_google_rpc_error_codes() {
+void Init_grpc_error_codes() {
   /* Constants representing the error codes of grpc_call_error in grpc.h */
-  VALUE rb_RpcErrors = rb_define_module_under(rb_mGoogleRpcCore, "RpcErrors");
+  VALUE rb_RpcErrors = rb_define_module_under(rb_mGrpcCore, "RpcErrors");
   rb_define_const(rb_RpcErrors, "OK", UINT2NUM(GRPC_CALL_OK));
   rb_define_const(rb_RpcErrors, "ERROR", UINT2NUM(GRPC_CALL_ERROR));
   rb_define_const(rb_RpcErrors, "NOT_ON_SERVER",
@@ -500,11 +500,11 @@
   rb_obj_freeze(rb_error_code_details);
 }
 
-void Init_google_rpc_call() {
+void Init_grpc_call() {
   /* CallError inherits from Exception to signal that it is non-recoverable */
   rb_eCallError =
-      rb_define_class_under(rb_mGoogleRpcCore, "CallError", rb_eException);
-  rb_cCall = rb_define_class_under(rb_mGoogleRpcCore, "Call", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "CallError", rb_eException);
+  rb_cCall = rb_define_class_under(rb_mGrpcCore, "Call", rb_cObject);
 
   /* Prevent allocation or inialization of the Call class */
   rb_define_alloc_func(rb_cCall, grpc_rb_cannot_alloc);
@@ -542,7 +542,7 @@
   hash_all_calls = rb_hash_new();
   rb_define_const(rb_cCall, "INTERNAL_ALL_CALLs", hash_all_calls);
 
-  Init_google_rpc_error_codes();
+  Init_grpc_error_codes();
 }
 
 /* Gets the call from the ruby object */
diff --git a/src/ruby/ext/grpc/rb_call.h b/src/ruby/ext/grpc/rb_call.h
index 965e9ee..3dbe0b3 100644
--- a/src/ruby/ext/grpc/rb_call.h
+++ b/src/ruby/ext/grpc/rb_call.h
@@ -54,6 +54,6 @@
 extern VALUE rb_eCallError;
 
 /* Initializes the Call class. */
-void Init_google_rpc_call();
+void Init_grpc_call();
 
 #endif /* GRPC_RB_CALL_H_ */
diff --git a/src/ruby/ext/grpc/rb_channel.c b/src/ruby/ext/grpc/rb_channel.c
index 7c98e66..e636564 100644
--- a/src/ruby/ext/grpc/rb_channel.c
+++ b/src/ruby/ext/grpc/rb_channel.c
@@ -227,9 +227,9 @@
 /* rb_cChannel is the ruby class that proxies grpc_channel. */
 VALUE rb_cChannel = Qnil;
 
-void Init_google_rpc_channel() {
+void Init_grpc_channel() {
   rb_cChannelArgs = rb_define_class("TmpChannelArgs", rb_cObject);
-  rb_cChannel = rb_define_class_under(rb_mGoogleRpcCore, "Channel", rb_cObject);
+  rb_cChannel = rb_define_class_under(rb_mGrpcCore, "Channel", rb_cObject);
 
   /* Allocates an object managed by the ruby runtime */
   rb_define_alloc_func(rb_cChannel, grpc_rb_channel_alloc);
diff --git a/src/ruby/ext/grpc/rb_channel.h b/src/ruby/ext/grpc/rb_channel.h
index 6c1210e..9315545 100644
--- a/src/ruby/ext/grpc/rb_channel.h
+++ b/src/ruby/ext/grpc/rb_channel.h
@@ -41,7 +41,7 @@
 extern VALUE rb_cChannel;
 
 /* Initializes the Channel class. */
-void Init_google_rpc_channel();
+void Init_grpc_channel();
 
 /* Gets the wrapped channel from the ruby wrapper */
 grpc_channel* grpc_rb_get_wrapped_channel(VALUE v);
diff --git a/src/ruby/ext/grpc/rb_completion_queue.c b/src/ruby/ext/grpc/rb_completion_queue.c
index 47776a9..e406336 100644
--- a/src/ruby/ext/grpc/rb_completion_queue.c
+++ b/src/ruby/ext/grpc/rb_completion_queue.c
@@ -159,9 +159,9 @@
 /* rb_cCompletionQueue is the ruby class that proxies grpc_completion_queue. */
 VALUE rb_cCompletionQueue = Qnil;
 
-void Init_google_rpc_completion_queue() {
+void Init_grpc_completion_queue() {
   rb_cCompletionQueue =
-      rb_define_class_under(rb_mGoogleRpcCore, "CompletionQueue", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "CompletionQueue", rb_cObject);
 
   /* constructor: uses an alloc func without an initializer. Using a simple
      alloc func works here as the grpc header does not specify any args for
diff --git a/src/ruby/ext/grpc/rb_completion_queue.h b/src/ruby/ext/grpc/rb_completion_queue.h
index c563662..a8155b5 100644
--- a/src/ruby/ext/grpc/rb_completion_queue.h
+++ b/src/ruby/ext/grpc/rb_completion_queue.h
@@ -45,6 +45,6 @@
 extern VALUE rb_cCompletionQueue;
 
 /* Initializes the CompletionQueue class. */
-void Init_google_rpc_completion_queue();
+void Init_grpc_completion_queue();
 
 #endif /* GRPC_RB_COMPLETION_QUEUE_H_ */
diff --git a/src/ruby/ext/grpc/rb_credentials.c b/src/ruby/ext/grpc/rb_credentials.c
index 87a5d0a..44b2d03 100644
--- a/src/ruby/ext/grpc/rb_credentials.c
+++ b/src/ruby/ext/grpc/rb_credentials.c
@@ -245,9 +245,9 @@
 /* rb_cCredentials is the ruby class that proxies grpc_credentials. */
 VALUE rb_cCredentials = Qnil;
 
-void Init_google_rpc_credentials() {
+void Init_grpc_credentials() {
   rb_cCredentials =
-      rb_define_class_under(rb_mGoogleRpcCore, "Credentials", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "Credentials", rb_cObject);
 
   /* Allocates an object managed by the ruby runtime */
   rb_define_alloc_func(rb_cCredentials, grpc_rb_credentials_alloc);
diff --git a/src/ruby/ext/grpc/rb_credentials.h b/src/ruby/ext/grpc/rb_credentials.h
index fada363..efa30a2 100644
--- a/src/ruby/ext/grpc/rb_credentials.h
+++ b/src/ruby/ext/grpc/rb_credentials.h
@@ -42,7 +42,7 @@
 extern VALUE rb_cCredentials;
 
 /* Initializes the ruby Credentials class. */
-void Init_google_rpc_credentials();
+void Init_grpc_credentials();
 
 /* Gets the wrapped credentials from the ruby wrapper */
 grpc_credentials* grpc_rb_get_wrapped_credentials(VALUE v);
diff --git a/src/ruby/ext/grpc/rb_event.c b/src/ruby/ext/grpc/rb_event.c
index 72c9dd2..38a90c1 100644
--- a/src/ruby/ext/grpc/rb_event.c
+++ b/src/ruby/ext/grpc/rb_event.c
@@ -312,10 +312,10 @@
    rpc event processing. */
 VALUE rb_eEventError = Qnil;
 
-void Init_google_rpc_event() {
+void Init_grpc_event() {
   rb_eEventError =
-      rb_define_class_under(rb_mGoogleRpcCore, "EventError", rb_eStandardError);
-  rb_cEvent = rb_define_class_under(rb_mGoogleRpcCore, "Event", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "EventError", rb_eStandardError);
+  rb_cEvent = rb_define_class_under(rb_mGrpcCore, "Event", rb_cObject);
 
   /* Prevent allocation or inialization from ruby. */
   rb_define_alloc_func(rb_cEvent, grpc_rb_cannot_alloc);
@@ -332,7 +332,7 @@
 
   /* Constants representing the completion types */
   rb_mCompletionType =
-      rb_define_module_under(rb_mGoogleRpcCore, "CompletionType");
+      rb_define_module_under(rb_mGrpcCore, "CompletionType");
   rb_define_const(rb_mCompletionType, "QUEUE_SHUTDOWN",
                   INT2NUM(GRPC_QUEUE_SHUTDOWN));
   rb_define_const(rb_mCompletionType, "OP_COMPLETE", INT2NUM(GRPC_OP_COMPLETE));
diff --git a/src/ruby/ext/grpc/rb_event.h b/src/ruby/ext/grpc/rb_event.h
index a406e9e..591a352 100644
--- a/src/ruby/ext/grpc/rb_event.h
+++ b/src/ruby/ext/grpc/rb_event.h
@@ -48,6 +48,6 @@
 VALUE grpc_rb_new_event(grpc_event *ev);
 
 /* Initializes the Event and EventError classes. */
-void Init_google_rpc_event();
+void Init_grpc_event();
 
 #endif /* GRPC_RB_EVENT_H_ */
diff --git a/src/ruby/ext/grpc/rb_metadata.c b/src/ruby/ext/grpc/rb_metadata.c
index 88eb62a..55a429c 100644
--- a/src/ruby/ext/grpc/rb_metadata.c
+++ b/src/ruby/ext/grpc/rb_metadata.c
@@ -187,9 +187,9 @@
 
 /* rb_cMetadata is the Metadata class whose instances proxy grpc_metadata. */
 VALUE rb_cMetadata = Qnil;
-void Init_google_rpc_metadata() {
+void Init_grpc_metadata() {
   rb_cMetadata =
-      rb_define_class_under(rb_mGoogleRpcCore, "Metadata", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "Metadata", rb_cObject);
 
   /* Allocates an object managed by the ruby runtime */
   rb_define_alloc_func(rb_cMetadata, grpc_rb_metadata_alloc);
diff --git a/src/ruby/ext/grpc/rb_metadata.h b/src/ruby/ext/grpc/rb_metadata.h
index 329ef15..8e452b6 100644
--- a/src/ruby/ext/grpc/rb_metadata.h
+++ b/src/ruby/ext/grpc/rb_metadata.h
@@ -48,6 +48,6 @@
 grpc_metadata* grpc_rb_get_wrapped_metadata(VALUE v);
 
 /* Initializes the Metadata class. */
-void Init_google_rpc_metadata();
+void Init_grpc_metadata();
 
 #endif /* GRPC_RB_METADATA_H_ */
diff --git a/src/ruby/ext/grpc/rb_server.c b/src/ruby/ext/grpc/rb_server.c
index e68843e..b2877e9 100644
--- a/src/ruby/ext/grpc/rb_server.c
+++ b/src/ruby/ext/grpc/rb_server.c
@@ -251,8 +251,8 @@
   return INT2NUM(recvd_port);
 }
 
-void Init_google_rpc_server() {
-  rb_cServer = rb_define_class_under(rb_mGoogleRpcCore, "Server", rb_cObject);
+void Init_grpc_server() {
+  rb_cServer = rb_define_class_under(rb_mGrpcCore, "Server", rb_cObject);
 
   /* Allocates an object managed by the ruby runtime */
   rb_define_alloc_func(rb_cServer, grpc_rb_server_alloc);
diff --git a/src/ruby/ext/grpc/rb_server.h b/src/ruby/ext/grpc/rb_server.h
index 92047ef..d9c6362 100644
--- a/src/ruby/ext/grpc/rb_server.h
+++ b/src/ruby/ext/grpc/rb_server.h
@@ -42,7 +42,7 @@
 extern VALUE rb_cServer;
 
 /* Initializes the Server class. */
-void Init_google_rpc_server();
+void Init_grpc_server();
 
 /* Gets the wrapped server from the ruby wrapper */
 grpc_server* grpc_rb_get_wrapped_server(VALUE v);
diff --git a/src/ruby/ext/grpc/rb_server_credentials.c b/src/ruby/ext/grpc/rb_server_credentials.c
index 4f6c67e..f825297 100644
--- a/src/ruby/ext/grpc/rb_server_credentials.c
+++ b/src/ruby/ext/grpc/rb_server_credentials.c
@@ -184,9 +184,9 @@
    grpc_server_credentials. */
 VALUE rb_cServerCredentials = Qnil;
 
-void Init_google_rpc_server_credentials() {
+void Init_grpc_server_credentials() {
   rb_cServerCredentials =
-      rb_define_class_under(rb_mGoogleRpcCore, "ServerCredentials", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "ServerCredentials", rb_cObject);
 
   /* Allocates an object managed by the ruby runtime */
   rb_define_alloc_func(rb_cServerCredentials, grpc_rb_server_credentials_alloc);
diff --git a/src/ruby/ext/grpc/rb_server_credentials.h b/src/ruby/ext/grpc/rb_server_credentials.h
index 2a2e1fb..2be6277 100644
--- a/src/ruby/ext/grpc/rb_server_credentials.h
+++ b/src/ruby/ext/grpc/rb_server_credentials.h
@@ -42,7 +42,7 @@
 extern VALUE rb_cServerCredentials;
 
 /* Initializes the ruby ServerCredentials class. */
-void Init_google_rpc_server_credentials();
+void Init_grpc_server_credentials();
 
 /* Gets the wrapped server_credentials from the ruby wrapper */
 grpc_server_credentials* grpc_rb_get_wrapped_server_credentials(VALUE v);
diff --git a/src/ruby/ext/grpc/rb_grpc.c b/src/ruby/ext/grpc/rb_grpc.c
index 8feefb0..c8e2bb5 100644
--- a/src/ruby/ext/grpc/rb_grpc.c
+++ b/src/ruby/ext/grpc/rb_grpc.c
@@ -153,10 +153,10 @@
   return t;
 }
 
-void Init_google_status_codes() {
+void Init_grpc_status_codes() {
   /* Constants representing the status codes or grpc_status_code in status.h */
   VALUE rb_mStatusCodes =
-      rb_define_module_under(rb_mGoogleRpcCore, "StatusCodes");
+      rb_define_module_under(rb_mGrpcCore, "StatusCodes");
   rb_define_const(rb_mStatusCodes, "OK", INT2NUM(GRPC_STATUS_OK));
   rb_define_const(rb_mStatusCodes, "CANCELLED", INT2NUM(GRPC_STATUS_CANCELLED));
   rb_define_const(rb_mStatusCodes, "UNKNOWN", INT2NUM(GRPC_STATUS_UNKNOWN));
@@ -214,11 +214,11 @@
 }
 
 /* Adds a module with constants that map to gpr's static timeval structs. */
-void Init_google_time_consts() {
+void Init_grpc_time_consts() {
   VALUE rb_mTimeConsts =
-      rb_define_module_under(rb_mGoogleRpcCore, "TimeConsts");
+      rb_define_module_under(rb_mGrpcCore, "TimeConsts");
   rb_cTimeVal =
-      rb_define_class_under(rb_mGoogleRpcCore, "TimeSpec", rb_cObject);
+      rb_define_class_under(rb_mGrpcCore, "TimeSpec", rb_cObject);
   rb_define_const(rb_mTimeConsts, "ZERO",
                   Data_Wrap_Struct(rb_cTimeVal, GC_NOT_MARKED, GC_DONT_FREE,
                                    (void *)&gpr_time_0));
@@ -240,37 +240,35 @@
 
 void grpc_rb_shutdown(void *vm) { grpc_shutdown(); }
 
 /* Initialize the Google RPC module structs */
 
 /* rb_sNewServerRpc is the struct that holds new server rpc details. */
 VALUE rb_sNewServerRpc = Qnil;
 /* rb_sStatus is the struct that holds status details. */
 VALUE rb_sStatus = Qnil;
 
-/* Initialize the Google RPC module. */
-VALUE rb_mGoogle = Qnil;
-VALUE rb_mGoogleRPC = Qnil;
-VALUE rb_mGoogleRpcCore = Qnil;
+/* Initialize the GRPC module. */
+VALUE rb_mGRPC = Qnil;
+VALUE rb_mGrpcCore = Qnil;
 
 void Init_grpc() {
   grpc_init();
   ruby_vm_at_exit(grpc_rb_shutdown);
-  rb_mGoogle = rb_define_module("Google");
-  rb_mGoogleRPC = rb_define_module_under(rb_mGoogle, "RPC");
-  rb_mGoogleRpcCore = rb_define_module_under(rb_mGoogleRPC, "Core");
+  rb_mGRPC = rb_define_module("GRPC");
+  rb_mGrpcCore = rb_define_module_under(rb_mGRPC, "Core");
   rb_sNewServerRpc = rb_struct_define("NewServerRpc", "method", "host",
                                       "deadline", "metadata", NULL);
   rb_sStatus = rb_struct_define("Status", "code", "details", "metadata", NULL);
 
-  Init_google_rpc_byte_buffer();
-  Init_google_rpc_event();
-  Init_google_rpc_channel();
-  Init_google_rpc_completion_queue();
-  Init_google_rpc_call();
-  Init_google_rpc_credentials();
-  Init_google_rpc_metadata();
-  Init_google_rpc_server();
-  Init_google_rpc_server_credentials();
-  Init_google_status_codes();
-  Init_google_time_consts();
+  Init_grpc_byte_buffer();
+  Init_grpc_event();
+  Init_grpc_channel();
+  Init_grpc_completion_queue();
+  Init_grpc_call();
+  Init_grpc_credentials();
+  Init_grpc_metadata();
+  Init_grpc_server();
+  Init_grpc_server_credentials();
+  Init_grpc_status_codes();
+  Init_grpc_time_consts();
 }
@@ -240,37 +240,35 @@
 void grpc_rb_shutdown(void *vm) { grpc_shutdown(); }
 
-/* Initialize the Google RPC module structs */
+/* Initialize the GRPC module structs */
 
 /* rb_sNewServerRpc is the struct that holds new server rpc details. */
diff --git a/src/ruby/ext/grpc/rb_grpc.h b/src/ruby/ext/grpc/rb_grpc.h
index d5e8930..664b94f 100644
--- a/src/ruby/ext/grpc/rb_grpc.h
+++ b/src/ruby/ext/grpc/rb_grpc.h
@@ -38,11 +38,8 @@
 #include <ruby.h>
 #include <grpc/support/time.h>
 
-/* rb_mGoogle is the top-level Google module. */
-extern VALUE rb_mGoogle;
-
-/* rb_mGoogleRpcCore is the module containing the ruby wrapper GRPC classes. */
-extern VALUE rb_mGoogleRpcCore;
+/* rb_mGrpcCore is the module containing the ruby wrapper GRPC classes. */
+extern VALUE rb_mGrpcCore;
 
 /* Class used to wrap timeval structs. */
 extern VALUE rb_cTimeVal;